@@ -1,4 +1,5 @@
 import json
+import re
 from typing import List
 
 from pygments import highlight
@@ -49,4 +50,24 @@ def print_response(response: Response) -> None:
                            TerminalFormatter())
     except ValueError as e:
         result = highlight(response.content.decode("utf-8"), TexLexer(), TerminalFormatter())
-    print(result)
\ No newline at end of file
+    print(result)
+
+
+def join(split_command):
+    """Return a shell-escaped string from *split_command*."""
+    return ' '.join(quote(arg) for arg in split_command)
+
+
+_find_unsafe = re.compile(r'[^\w@%+=:,./-]', re.ASCII).search
+
+
+def quote(s):
+    """Return a shell-escaped version of the string *s*."""
+    if not s:
+        return "''"
+    if _find_unsafe(s) is None:
+        return s
+
+    # use single quotes, and put single quotes into double quotes
+    # the string $'b is then quoted as '$'"'"'b'
+    return "'" + s.replace("'", "'\"'\"'") + "'"
